/**
 * 
 */
package ch.ethz.se.rpnc.visitor;

import ch.ethz.se.rpnc.node.DivideByOperator;
import ch.ethz.se.rpnc.node.MinusOperator;
import ch.ethz.se.rpnc.node.Operand;
import ch.ethz.se.rpnc.node.PlusOperator;
import ch.ethz.se.rpnc.node.TimesOperator;

/**
 * Visitor interface for nodes (Visitor pattern).
 */
public interface Visitor
{
	/**
	 * Visit operand.
	 * @param o Operand to visit.
	 */
	public void visit(Operand o);

	/**
	 * Visit plus-operator.
	 * @param o Operator to visit. 
	 * @throws Exception 
	 */
	public void visit(PlusOperator o) throws Exception;

	/**
	 * Visit minus-operator.
	 * @param o Operand to visit.
	 * @throws Exception 
	 */
	public void visit(MinusOperator o) throws Exception;
	
	/**
	 * Visit times-operator.
	 * @param o Operand to visit.
	 * @throws Exception 
	 */
	public void visit(TimesOperator o) throws Exception;
	
	/**
	 * Visit DivideBy-operator.
	 * @param o Operand to visit.
	 * @throws Exception
	 */
	public void visit(DivideByOperator o) throws Exception;
}
